@@ -5,10 +5,6 @@ ydat  <-  c(5.308, 7.24, 9.638, 12.866, 17.069, 23.192, 31.443,
           38.558, 50.156, 62.948, 75.995, 91.972) # for testing
 tdat  <-  seq_along(ydat) # for testing
 
-# A simple starting vector -- must have named parameters for nlxb, nls, wrapnlsr.
-start1  <-  c(b1=1, b2=1, b3=1)
-startf1  <-  c(b1=1, b2=1, b3=.1)
-
 eunsc  <-   y ~ b1/(1+b2*exp(-b3*tt))
 
 cat("LOCAL DATA IN DATA FRAMES\n")
